/*
 * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __BUILDRANGES_H__
#define __BUILDRANGES_H__

#include <gnome.h>
#include <libdc1394/dc1394_control.h>
#include "definitions.h"
#include "support.h"
#include "callbacks.h"

void
BuildRange(int feature);

void
BuildEmptyRange(int feature);

void 
BuildFormat7Ranges(void);

void
BuildFormat7BppRange(void);

#endif
